/**
 *  Copyright (c) 2010 A.G.Docherty. All Rights Reserved.
 */

package uk.co.keang.sudoku.solver;

import static org.junit.Assert.assertTrue;

import java.util.Arrays;

import org.junit.Before;
import org.junit.Test;

import uk.co.keang.sudoku.Puzzle;
import uk.co.keang.sudoku.Puzzle.Cell;
import uk.co.keang.sudoku.SudokuSolver;
import uk.co.keang.sudoku.event.IllegalGridException;

/**
 * @author A.G.Docherty
 *
 */
public class ZeroChoiceSolverTest
{

private Cell[][] grid;
private final String[] args = new String[] { "294135876813746925657298143926813754735964281148572369579621438382459617461387592" };
private SudokuSolver sudoku;
private Puzzle puzzle;

/**
 * @throws java.lang.Exception
 */
@Before
public void setUp() throws Exception
	{
	sudoku = new SudokuSolver(args);
	puzzle = sudoku.getPuzzle();
	grid = puzzle.getGrid();
	}

/**
 * Test method for {@link uk.co.keang.sudoku.solver.ZeroChoiceSolver#findSolutions()}.
 * @throws IllegalGridException 
 */
@Test
public void testFindSolutions() throws IllegalGridException
	{
	puzzle.set(0, 0, new Cell(Arrays.asList(1, 2, 3)));
	puzzle.set(0, 1, new Cell(Arrays.asList(1, 3)));
	puzzle.set(0, 2, new Cell(Arrays.asList(1, 3, 4)));
	
	assertTrue(grid[0][0].size() > 1);
	assertTrue(grid[0][1].size() > 1);
	assertTrue(grid[0][2].size() > 1);
	
	ZeroChoiceSolver solver = new ZeroChoiceSolver(puzzle);
	solver.findSolutions();

	assertTrue(grid[0][0].size() == 1);
	assertTrue(grid[0][1].size() > 1);
	assertTrue(grid[0][2].size() > 1);
	}

}
